@@ -25,11 +25,12 @@ class CodeImpThread;
 class ClassImport
 {
 public:
-    ClassImport(CodeImpThread* thread = 0) : m_thread(thread), m_enabled(true) {}
-    virtual ~ClassImport() {}
+    ClassImport(CodeImpThread* thread = 0);
+    virtual ~ClassImport();
 
     bool importFiles(const QStringList& fileNames);
     bool importFile(const QString& fileName);
+    void setRootPath(const QString &path);
 
     /**
      * Return state of the importer. It may be disabled because of 
@@ -65,6 +66,7 @@ protected:
 
     CodeImpThread* m_thread;  ///< thread in which the work of importing is done
     bool m_enabled;           ///< state of importer
+    QString m_rootPath;       ///< root path of import
 };
 
 #endif
