@@ -19,6 +19,7 @@
 #include "entitywidget.h"
 #include "floatingtextwidget.h"
 #include "forkjoinwidget.h"
+#include "interfacewidget.h"
 #include "notewidget.h"
 #include "objectwidget.h"
 #include "objectnodewidget.h"
@@ -37,7 +38,7 @@ static const bool CHECKABLE = true;
  * Constructs the popup menu for a scene widget.
  *
  * @param parent   The parent to ListPopupMenu.
- * @param object   The WidgetBase to represent a menu for.
+ * @param widget   The WidgetBase to represent a menu for.
  * @param multi    True if multiple items are selected.
  * @param uniqueType The type of widget shared by all selected widgets
  */
@@ -208,7 +209,7 @@ void WidgetBasePopupMenu::insertSingleSelectionMenu(WidgetBase* widget)
 
     case WidgetBase::wt_Interface:
         {
-            ClassifierWidget* c = widget->asClassifierWidget();
+            InterfaceWidget* c = widget->asInterfaceWidget();
             if (!c)
                 break;
             insertSubMenuNew(type);
@@ -277,6 +278,7 @@ void WidgetBasePopupMenu::insertSingleSelectionMenu(WidgetBase* widget)
             if (ft == 0)
                 m_actions[mt_NameAsTooltip]->setChecked(true);
         }
+        insert(mt_Delete);
         insert(mt_Properties);
         break;
 
@@ -629,21 +631,21 @@ void WidgetBasePopupMenu::insertSubMenuNew(WidgetBase::WidgetType type, KMenu *m
             insert(mt_Artifact, menu);
             break;
         case WidgetBase::wt_Class:
-            insert(mt_Attribute, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Public_Attribute), i18n("Attribute..."));
-            insert(mt_Operation, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Public_Method), i18n("Operation..."));
-            insert(mt_Template, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Template_New), i18n("Template..."));
-            insert(mt_Class, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Class), i18nc("new class menu item", "Class..."));
-            insert(mt_Interface, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Interface), i18n("Interface..."));
-            insert(mt_Datatype, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Datatype), i18n("Datatype..."));
-            insert(mt_Enum, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Enum), i18n("Enum..."));
+            insert(mt_Attribute, menu);
+            insert(mt_Operation, menu);
+            insert(mt_Template, menu);
+            insert(mt_Class, menu);
+            insert(mt_Interface, menu);
+            insert(mt_Datatype, menu);
+            insert(mt_Enum, menu);
             break;
         case WidgetBase::wt_Interface:
-            insert(mt_Operation, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Public_Method), i18n("Operation..."));
-            insert(mt_Template, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Template_New), i18n("Template..."));
-            insert(mt_Class, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Class), i18nc("new class menu item", "Class..."));
-            insert(mt_Interface, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Interface), i18n("Interface..."));
-            insert(mt_Datatype, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Datatype), i18n("Datatype..."));
-            insert(mt_Enum, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Enum), i18n("Enum..."));
+            insert(mt_Operation, menu);
+            insert(mt_Template, menu);
+            insert(mt_Class, menu);
+            insert(mt_Interface, menu);
+            insert(mt_Datatype, menu);
+            insert(mt_Enum, menu);
             break;
         case WidgetBase::wt_Entity:
             insert(mt_EntityAttribute, menu);
