@@ -14,6 +14,7 @@
 // application includes
 #include "associationwidget.h"
 #include "debug_utils.h"
+#include "optionstate.h"
 #include "uml.h"
 #include "umldoc.h"
 #include "umlwidget.h"
@@ -47,12 +48,15 @@ AssociationLine::AssociationLine(AssociationWidget *association)
     m_subsetSymbol(0),
     m_collaborationLineItem(0),
     m_collaborationLineHead(0),
-    m_layout(Polyline)
+    m_layout(Settings::optionState().generalState.layoutType),
+    m_autoLayoutSpline(true)
 {
     Q_ASSERT(association);
     setFlag(QGraphicsLineItem::ItemIsSelectable);
     setAcceptHoverEvents(true);
     setZValue(3);
+    //setLayout(Uml::LayoutType::Spline);
+    //createSplinePoints();
 }
 
 /**
@@ -60,6 +64,10 @@ AssociationLine::AssociationLine(AssociationWidget *association)
  */
 AssociationLine::~AssociationLine()
 {
+    delete m_startSymbol;
+    delete m_endSymbol;
+    delete m_subsetSymbol;
+    removeCollaborationLine();
 }
 
 /**
@@ -258,6 +266,22 @@ bool AssociationLine::isEndSegmentIndex(int index) const
     return (index == 0 || index == (size - 1));
 }
 
+bool AssociationLine::isAutoLayouted() const
+{
+    return m_autoLayoutSpline;
+}
+
+bool AssociationLine::enableAutoLayout()
+{
+    m_autoLayoutSpline = true;
+    createSplinePoints();
+    path();
+    createSplinePoints();
+    path();
+    update();
+    return true;
+}
+
 /**
  * Sets the start and end points.
  */
@@ -298,10 +322,10 @@ void AssociationLine::dumpPoints()
 /**
  * Loads AssociationLine information saved in \a qElement XMI element.
  */
-bool AssociationLine::loadFromXMI(QDomElement &qElement)
+bool AssociationLine::loadFromXMI1(QDomElement &qElement)
 {
     QString layout = qElement.attribute(QLatin1String("layout"), QLatin1String("polyline"));
-    m_layout = fromString(layout);
+    m_layout = Uml::LayoutType::fromString(layout);
 
     QDomNode node = qElement.firstChild();
 
@@ -316,7 +340,7 @@ bool AssociationLine::loadFromXMI(QDomElement &qElement)
     qreal nX = toDoubleFromAnyLocale(x);
     QString y = startElement.attribute(QLatin1String("starty"), QLatin1String("0"));
     qreal nY = toDoubleFromAnyLocale(y);
-    QPointF startPoint(nX * dpiScale, nY * dpiScale);
+    QPointF startPoint(nX, nY);
 
     node = startElement.nextSibling();
     QDomElement endElement = node.toElement();
@@ -327,7 +351,7 @@ bool AssociationLine::loadFromXMI(QDomElement &qElement)
     nX = toDoubleFromAnyLocale(x);
     y = endElement.attribute(QLatin1String("endy"), QLatin1String("0"));
     nY = toDoubleFromAnyLocale(y);
-    QPointF endPoint(nX * dpiScale, nY * dpiScale);
+    QPointF endPoint(nX, nY);
     setEndPoints(startPoint * dpiScale, endPoint * dpiScale);
     QPointF point;
     node = endElement.nextSibling();
@@ -352,10 +376,10 @@ bool AssociationLine::loadFromXMI(QDomElement &qElement)
  * Saves association line information into XMI element named "linepath".
  * @note Stored as linepath for backwared compatibility
  */
-void AssociationLine::saveToXMI(QDomDocument &qDoc, QDomElement &qElement)
+void AssociationLine::saveToXMI1(QDomDocument &qDoc, QDomElement &qElement)
 {
     QDomElement lineElement = qDoc.createElement(QLatin1String("linepath"));
-    lineElement.setAttribute(QLatin1String("layout"), toString(m_layout));
+    lineElement.setAttribute(QLatin1String("layout"), Uml::LayoutType::toString(m_layout));
     QDomElement startElement = qDoc.createElement(QLatin1String("startpoint"));
 
     qreal dpiScale = UMLApp::app()->document()->dpiScale();
@@ -626,9 +650,8 @@ void AssociationLine::createCollaborationLine()
 {
     const QPen p = pen();
 
-    // recreate
-    delete m_collaborationLineItem;
-    delete m_collaborationLineHead;
+    //recreate
+    removeCollaborationLine();
 
     m_collaborationLineItem = new QGraphicsLineItem(m_associationWidget);
     m_collaborationLineItem->setPen(p);
@@ -726,20 +749,20 @@ QPainterPath AssociationLine::path() const
     if (m_points.count() > 0) {
         QPainterPath path;
         switch (m_layout) {
-        case Direct:
+        case Uml::LayoutType::Direct:
             path.moveTo(m_points.first());
             path.lineTo(m_points.last());
             break;
 
-        case Spline:
+        case Uml::LayoutType::Spline:
             path = createBezierCurve(m_points);
             break;
 
-        case Orthogonal:
+        case Uml::LayoutType::Orthogonal:
             path = createOrthogonalPath(m_points);
             break;
 
-        case Polyline:
+        case Uml::LayoutType::Polyline:
         default:
             QPolygonF polygon(m_points);
             path.addPolygon(polygon);
@@ -780,30 +803,30 @@ QPainterPath AssociationLine::shape() const
 /**
  * Convert enum LayoutType to string.
  */
-QString AssociationLine::toString(LayoutType layout)
+QString AssociationLine::toString(Uml::LayoutType::Enum layout)
 {
-    return QLatin1String(ENUM_NAME(AssociationLine, LayoutType, layout));
+    return Uml::LayoutType::toString(layout);
 }
 
 /**
  * Convert string to enum LayoutType.
  */
-AssociationLine::LayoutType AssociationLine::fromString(const QString &layout)
+Uml::LayoutType::Enum AssociationLine::fromString(const QString &layout)
 {
     if (layout == QLatin1String("Direct"))
-        return Direct;
+        return Uml::LayoutType::Direct;
     if (layout == QLatin1String("Spline"))
-        return Spline;
+        return Uml::LayoutType::Spline;
     if (layout == QLatin1String("Orthogonal"))
-        return Orthogonal;
-    return Polyline;
+        return Uml::LayoutType::Orthogonal;
+    return Uml::LayoutType::Polyline;
 }
 
 /**
  * Return the layout type of the association line.
  * @return   the currently used layout
  */
-AssociationLine::LayoutType AssociationLine::layout() const
+Uml::LayoutType::Enum AssociationLine::layout() const
 {
     return m_layout;
 }
@@ -812,12 +835,12 @@ AssociationLine::LayoutType AssociationLine::layout() const
  * Set the layout type of the association line.
  * @param layout   the desired layout to set
  */
-void AssociationLine::setLayout(LayoutType layout)
+void AssociationLine::setLayout(Uml::LayoutType::Enum layout)
 {
     prepareGeometryChange();
     m_layout = layout;
-    DEBUG(DBG_SRC) << "new layout = " << toString(m_layout);
-    if (m_layout == Spline) {
+    DEBUG(DBG_SRC) << "new layout = " << Uml::LayoutType::toString(m_layout);
+    if (m_layout == Uml::LayoutType::Spline) {
         createSplinePoints();
     }
     alignSymbols();
@@ -830,20 +853,60 @@ void AssociationLine::setLayout(LayoutType layout)
  */
 void AssociationLine::createSplinePoints()
 {
-    if (m_points.size() == 2) {  // create two points
-        QPointF p1 = m_points.first();  // start point
-        QPointF p2 = m_points.last();   // end point
+    QPointF c1, c2;
+    QPointF p1 = m_points.first();  // start point
+    QPointF p2 = m_points.last();   // end point
+        
+    if (m_autoLayoutSpline) {
         qreal dx = p2.x() - p1.x();
         qreal dy = p2.y() - p1.y();
-        qreal oneThirdX = 0.33 * dx;
+        /*qreal oneThirdX = 0.33 * dx;
         qreal oneThirdY = 0.33 * dy;
         QPointF c1(p1.x() + oneThirdX,  // control point 1
                    p1.y() - oneThirdY);
         QPointF c2(p2.x() - oneThirdX,  // control point 2
-                   p2.y() + oneThirdY);
+                   p2.y() + oneThirdY);*/
+        qreal oneHalfX = 0.5 * dx;
+        qreal oneHalfY = 0.5 * dy;
+        if (dx > dy) {
+            c1dx = oneHalfX;
+            c1dy = 0;
+            c2dx = -oneHalfX;
+            c2dy = 0;
+        }
+        else {
+            c1dx = 0;
+            c1dy = oneHalfY;
+            c2dx = 0;
+            c2dy = -oneHalfY;
+        }
+        
+        c1 = QPointF(p1.x() + c1dx,  // control point 1
+                p1.y() + c1dy);
+        c2 = QPointF(p2.x() + c2dx,  // control point 2
+                p2.y() + c2dy);
+    } else {
+        //c1 = m_points[1];
+        //c2 = m_points[2];
+        
+        //c1dx = c1.x() - p1.x();
+        //c1dy = c1.y() - p1.y();
+        //c2dx = c2.x() - p2.x();
+        //c2dy = c2.y() - p2.y();
+        
+        c1 = QPointF(p1.x() + c1dx,  // control point 1
+                    p1.y() + c1dy);
+        c2 = QPointF(p2.x() + c2dx,  // control point 2
+                    p2.y() + c2dy);
+    }
+    if (m_points.size() == 2) {  // create two points
         insertPoint(1, c1);
         insertPoint(2, c2);
     }
+    if (m_points.size() == 4) {  // change bezier points
+        setPoint(1, c1);
+        setPoint(2, c2);
+    }
     if (m_points.size() == 3) {  // create one point
         // insertPoint(1 or 2, );
         // Note: For now we use a quadratic Bezier curve in createBezierCurve(...).
@@ -857,6 +920,8 @@ void AssociationLine::createSplinePoints()
  */
 QPainterPath AssociationLine::createBezierCurve(QVector<QPointF> points)
 {
+    std::string autoLayout;
+
     QPainterPath path;
     if (points.size() > 3) {  // cubic Bezier curve(s)
         path.moveTo(points.at(0));
@@ -996,6 +1061,23 @@ void AssociationLine::paint(QPainter* painter, const QStyleOptionGraphicsItem* o
                 painter->drawRect(circle);
             }
         }
+        
+        //circle.moveCenter(savedStart);
+        //painter->drawRect(circle);
+        
+        // draw bezier handles
+        if (m_layout == Uml::LayoutType::Spline) {
+            for (int i = 2; i < sz-1; ++i) {
+                painter->setPen(QPen(invertedColor, _pen.widthF() + 1));
+                //    if(m_layout == Uml::LayoutType::Spline) {
+                QLineF mysegmentLine(savedStart, m_points[i-1]);
+                painter->drawLine(mysegmentLine);
+                
+                QLineF mysegmentLine2(m_points[i], savedEnd);
+                painter->drawLine(mysegmentLine2);
+            }            
+        }
+        
         circle.moveCenter(savedEnd);
         painter->drawRect(circle);
 
@@ -1008,7 +1090,7 @@ void AssociationLine::paint(QPainter* painter, const QStyleOptionGraphicsItem* o
             painter->drawEllipse(circle);
         }
         else if (m_activeSegmentIndex != -1) {
-            if (m_layout == Polyline) {
+            if (m_layout == Uml::LayoutType::Polyline) {
                 painter->setPen(QPen(invertedColor, _pen.widthF() + 1));
                 painter->setBrush(Qt::NoBrush);
 
@@ -1016,6 +1098,7 @@ void AssociationLine::paint(QPainter* painter, const QStyleOptionGraphicsItem* o
                 painter->drawLine(segmentLine);
             }
         }
+        
         // debug info
         if (Tracer::instance()->isEnabled(QString::fromLatin1(metaObject()->className()))) {
             painter->setPen(Qt::green);
@@ -1100,7 +1183,15 @@ void AssociationLine::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 
     if (m_activePointIndex != -1) {
         // Move a single point (snap behaviour)
+        if (m_activePointIndex == 1) {
+            c1dx = newPos.x() - m_points.at(0).x();
+            c1dy = newPos.y() - m_points.at(0).y();
+        } else if (m_activePointIndex == 2) {
+            c2dx = newPos.x() - m_points.at(3).x();
+            c2dy = newPos.y() - m_points.at(3).y();
+        }
         setPoint(m_activePointIndex, newPos);
+        m_autoLayoutSpline = false;
     }
     else if (m_activeSegmentIndex != -1 && !isEndSegmentIndex(m_activeSegmentIndex)) {
         // Move a segment (between two points, snap behaviour not implemented)
