@@ -22,6 +22,7 @@
 #include "docwindow.h"
 #include "floatingtextwidget.h"
 #include "notewidget.h"
+#include "messagewidget.h"
 #include "object_factory.h"
 #include "idchangelog.h"
 #include "menus/listpopupmenu.h"
@@ -869,6 +870,14 @@ void UMLWidget::slotMenuSelection(QAction *trigger)
         break;
     }
 
+    case ListPopupMenu::mt_MessageSynchronous:
+//        MessageWidget *widget = new MessageWidget(umlScene(), this);
+//        addConnectedWidget(widget, Uml::AssociationType::Coll_Message_Synchronous);
+    case ListPopupMenu::mt_MessageAsynchronous:
+    case ListPopupMenu::mt_MessageFound:
+    case ListPopupMenu::mt_MessageLost:
+        break;
+
     default:
         WidgetBase::slotMenuSelection(trigger);
         break;
@@ -1378,8 +1387,16 @@ void UMLWidget::resize()
  */
 void UMLWidget::resize(QGraphicsSceneMouseEvent *me)
 {
-    // TODO the status message lies for at least MessageWidget which could only be resized vertical
-    UMLApp::app()->document()->writeToStatusBar(i18n("Hold shift or ctrl to move in X axis. Hold shift and control to move in Y axis. Right button click to cancel resize."));
+    QString msgX = i18n("Hold shift or control to move in X axis.");
+    QString msgY = i18n("Hold shift and control to move in Y axis.");
+    QString msg;
+    if (isMessageWidget())
+        msg = msgY;
+    else if (isObjectWidget())
+        msg = msgX;
+    else
+        msg = QString(QLatin1String("%1 %2")).arg(msgX, msgY);
+    UMLApp::app()->document()->writeToStatusBar(msg);
 
     m_resized = true;
 
